@@ -133,7 +133,16 @@ class ArchiveNode():
         if archived is True:
             queryset.update(
                 archived=True,
-                archive_points=ArrayAppend('archive_points', point)
+                archive_points=Case(
+                    When(
+                        archive_points__contains=[point],
+                        then=F('archive_points')
+                    ),
+                    default=ArrayAppend('archive_points', point),
+                    output_field=ArrayField(
+                        models.CharField(max_length=50),
+                    )
+                )
             )
 
         # If unarchiving the related objects. Then ensure the current
@@ -145,9 +154,12 @@ class ArchiveNode():
                     When(
                         archive_points__contains=[point],
                         archive_points__len=1,
-                        then=archived
+                        then=False
                     ),
-                    default=F('archived')
+                    default=F('archived'),
+                    output_field=ArrayField(
+                        models.CharField(max_length=50),
+                    )
                 ),
                 archive_points=ArrayRemove('archive_points', point)
             )
